package Net::Zuora::Invoice;
use Net::Zuora::ZObject;
use namespace::autoclean;

1;

=head1 NAME

Net::Zuora::Invoice - Class representing an Invoice in the Zuora system

=head1 AUTHOR

See L<Net::Zuora> for author information

=head1 COPYRIGHT & LICENSE

See L<Net::Zuora> for copyright and license information.

=cut

